---
name: Request support for a new operating system
about: Request compatibility with a new OS / older version of a provided OS
title: ''
labels: enhancement
assignees: ''

---

**What operating system are you requesting support for?**


**Other notes**
_I can't exactly test on every device (rather expensive!)_
_Therefore, for a vastly increased chance of this being added, it is helpful if you have a link to documentation, or access to this OS and some time free for me to test functionality with you._
